PyBaccarat: pybaccarat.baccaratsystems.BaccSys Class Reference

PyBaccarat visit the ministry of silly walks

Public Member Functions | Public Attributes | List of all members
pybaccarat.baccaratsystems.BaccSys Class Reference
Inheritance diagram for pybaccarat.baccaratsystems.BaccSys:

## Public Member Functions
def | __init__ (self, sys_name="")
def | new_shoe (self, burn_card, boards=None)
def | set_tie_object (self, tie_track)
def | set_bpt_object (self, bpt)
def | hand_pre (self, hand_num)
def | result_won (self, amount)
def | result_lost (self, amount)
def | hand_post (self, win_diff, player_hand, banker_hand)
def | end_shoe (self)
def | opposite_side (self, side)
def | play (self, side, size=1)
def | quit_this_shoe (self)
def | __init__ (self, sys_name="")
def | new_shoe (self, burn_card, boards=None)
def | set_tie_object (self, tie_track)
def | set_bpt_object (self, bpt)
def | hand_pre (self, hand_num)
def | result_won (self, amount)
def | result_lost (self, amount)
def | hand_post (self, win_diff, player_hand, banker_hand)
def | end_shoe (self)
def | opposite_side (self, side)
def | play (self, side, size=1)
def | quit_this_shoe (self)
def | print_WLseq (self)

## Public Attributes
| name
| hand_number
| play_on
| play_size
| won
| lost
| tied
| money
| scoreboards
| WLseq
| last_WLT
| quit_shoe
| tie_tracker
| bpt_tracker

The documentation for this class was generated from the following file:

- build/lib/pybaccarat/baccaratsystems.py